#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 
# System settings common constants and functions.
# 
# Author: JM. Philippe <jean-michel.philippe@doudoulinux.org>
#################################
# This file is part of DoudouLinux.
#
# DoudouLinux is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DoudouLinux is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DoudouLinux.  If not, see <http://www.gnu.org/licenses/>.

import sys, os, re, gettext, glob, subprocess, urllib2

############################
TEXTDOMAIN = "system-tools"
_MOfiles_recompiled = False

############################
# find the data directory
ScriptDir = os.path.dirname(__file__)
if os.path.isdir("/usr/share/system-tools"):
    # use the system directory
    DataDir = "/usr/share/system-tools"
else:
    # use the source code directory
    DataDir = os.path.abspath(
        os.path.join(ScriptDir, "..", "data")
    )
LOCALEDIR = os.path.join(ScriptDir, "..", ".locale")

############################
############################
############################
def geoloc_country():
    """
    Returns the country using IP geolocalization.
    You can change the URL used to perform IP/country guess if needed.
    """
    cur_country_code = None
    try:
        whatismyip = 'http://libs.doudoulinux.org/myip.php'
        ipjson = urllib2.urlopen(whatismyip, timeout=3).readlines()[0]
        ip = re.findall('\d+\.\d+\.\d+\.\d+', ipjson)[0]
        print "*** my IP = %s (JSON string: %s)" % (ip, ipjson)
        
        whatismyloc = 'http://freegeoip.net/json/' + ip
        locjson = urllib2.urlopen(whatismyloc, timeout=5).readlines()[0]
        cur_country_code = re.findall('"country_code":\s*"([^"]+)"', locjson)[0].lower()
        print "*** my location = %s (JSON string: %s)" % (cur_country_code, locjson)
    except:
        pass #best effort, we get here if we're not connected to the Internet
    
    return cur_country_code

############################
def recompile_pofiles():
    """
    Recompiles the PO files for use from the source code directory.
    """
    global TEXTDOMAIN, LOCALEDIR, ScriptDir
    
    PoDir = os.path.join(ScriptDir, "..", "po")
    for FileName in glob.glob("%s/*.po" % PoDir):
        LangCode = os.path.basename(FileName).split(".")[0]
        TargetDir = os.path.join(LOCALEDIR, LangCode, "LC_MESSAGES")
        TargetFile = os.path.join(TargetDir, TEXTDOMAIN + ".mo")
        if not os.path.isdir(TargetDir):
            subprocess.call("mkdir -p %s" % TargetDir, shell=True)
        subprocess.call("msgfmt -o %s %s" % (TargetFile, FileName), shell=True)

############################
def set_gettext_domain():
    """
    Restores the widgets gettext domain.
    """
    global TEXTDOMAIN, LOCALEDIR, _MOfiles_recompiled, ScriptDir
    
    PoDir = os.path.join(ScriptDir, "..", "po")
    if not os.path.isdir(PoDir):
        # use system wide MO files
        gettext.install(TEXTDOMAIN)
    else:
        # recompile and use source PO files
        if not _MOfiles_recompiled:
            recompile_pofiles()
            _MOfiles_recompiled = True
        gettext.install(TEXTDOMAIN, LOCALEDIR)

set_gettext_domain()
